@@ -4,8 +4,8 @@ from functools import wraps
 from ..common import _getJson
 
 
-def cryptoBook(symbol, token='', version='', filter=''):
-    '''This returns a current snapshot of the book for a specified cryptocurrency. For REST, you will receive a current snapshot of the current book for the specific cryptocurrency. For SSE Streaming, you will get a full representation of the book updated as often as the book changes. Examples of each are below:
+def cryptoBook(symbol, token="", version="", filter=""):
+    """This returns a current snapshot of the book for a specified cryptocurrency. For REST, you will receive a current snapshot of the current book for the specific cryptocurrency. For SSE Streaming, you will get a full representation of the book updated as often as the book changes. Examples of each are below:
 
     https://iexcloud.io/docs/api/#cryptocurrency-book
     continuous
@@ -18,17 +18,19 @@ def cryptoBook(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('/crypto/{symbol}/book'.format(symbol=symbol), token, version, filter)
+    """
+    return _getJson(
+        "/crypto/{symbol}/book".format(symbol=symbol), token, version, filter
+    )
 
 
 @wraps(cryptoBook)
-def cryptoBookDF(symbol, token='', version='', filter=''):
+def cryptoBookDF(symbol, token="", version="", filter=""):
     return pd.DataFrame(cryptoBook(symbol, token, version, filter))
 
 
-def cryptoPrice(symbol, token='', version='', filter=''):
-    '''This returns the price for a specified cryptocurrency.
+def cryptoPrice(symbol, token="", version="", filter=""):
+    """This returns the price for a specified cryptocurrency.
 
     https://iexcloud.io/docs/api/#cryptocurrency-price
     continuous
@@ -41,17 +43,19 @@ def cryptoPrice(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('/crypto/{symbol}/price'.format(symbol=symbol), token, version, filter)
+    """
+    return _getJson(
+        "/crypto/{symbol}/price".format(symbol=symbol), token, version, filter
+    )
 
 
 @wraps(cryptoPrice)
-def cryptoPriceDF(symbol, token='', version='', filter=''):
+def cryptoPriceDF(symbol, token="", version="", filter=""):
     return pd.DataFrame(cryptoPrice(symbol, token, version, filter))
 
 
-def cryptoQuote(symbol, token='', version='', filter=''):
-    '''This returns the quote for a specified cryptocurrency. Quotes are available via REST and SSE Streaming.
+def cryptoQuote(symbol, token="", version="", filter=""):
+    """This returns the quote for a specified cryptocurrency. Quotes are available via REST and SSE Streaming.
 
 
     https://iexcloud.io/docs/api/#cryptocurrency-quote
@@ -65,10 +69,12 @@ def cryptoQuote(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('/crypto/{symbol}/price'.format(symbol=symbol), token, version, filter)
+    """
+    return _getJson(
+        "/crypto/{symbol}/price".format(symbol=symbol), token, version, filter
+    )
 
 
 @wraps(cryptoQuote)
-def cryptoQuoteDF(symbol, token='', version='', filter=''):
+def cryptoQuoteDF(symbol, token="", version="", filter=""):
     return pd.DataFrame(cryptoQuote(symbol, token, version, filter))
