@@ -1,11 +1,20 @@
 # -*- coding: utf-8 -*-
 import pandas as pd
 from functools import wraps
-from ..common import _getJson, _getJsonAsync, _strToList, _raiseIfNotStr, _strOrDate, _reindex, _toDatetime
+from ..common import (
+    _getJson,
+    _getJsonAsync,
+    _strToList,
+    _raiseIfNotStr,
+    _strOrDate,
+    _reindex,
+    _toDatetime,
+    json_normalize,
+)
 
 
-def tops(symbols=None, token='', version=''):
-    '''TOPS provides IEX’s aggregated best quoted bid and offer position in near real time for all securities on IEX’s displayed limit order book.
+def tops(symbols=None, token="", version=""):
+    """TOPS provides IEX’s aggregated best quoted bid and offer position in near real time for all securities on IEX’s displayed limit order book.
     TOPS is ideal for developers needing both quote and trade data.
 
     https://iexcloud.io/docs/api/#tops
@@ -17,31 +26,33 @@ def tops(symbols=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     symbols = _strToList(symbols)
     if symbols:
-        return _getJson('tops?symbols=' + ','.join(symbols) + '%2b', token, version)
-    return _getJson('tops', token, version)
+        return _getJson("tops?symbols=" + ",".join(symbols) + "%2b", token, version)
+    return _getJson("tops", token, version)
 
 
 @wraps(tops)
-async def topsAsync(symbols=None, token='', version=''):
+async def topsAsync(symbols=None, token="", version=""):
     symbols = _strToList(symbols)
     if symbols:
-        return await _getJsonAsync('tops?symbols=' + ','.join(symbols) + '%2b', token, version)
-    return await _getJsonAsync('tops', token, version)
+        return await _getJsonAsync(
+            "tops?symbols=" + ",".join(symbols) + "%2b", token, version
+        )
+    return await _getJsonAsync("tops", token, version)
 
 
 @wraps(tops)
-def topsDF(symbols=None, token='', version=''):
-    df = pd.io.json.json_normalize(tops(symbols, token, version))
+def topsDF(symbols=None, token="", version=""):
+    df = json_normalize(tops(symbols, token, version))
     _toDatetime(df)
-    _reindex(df, 'symbol')
+    _reindex(df, "symbol")
     return df
 
 
-def last(symbols=None, token='', version=''):
-    '''Last provides trade data for executions on IEX. It is a near real time, intraday API that provides IEX last sale price, size and time.
+def last(symbols=None, token="", version=""):
+    """Last provides trade data for executions on IEX. It is a near real time, intraday API that provides IEX last sale price, size and time.
     Last is ideal for developers that need a lightweight stock quote.
 
     https://iexcloud.io/docs/api/#last
@@ -53,31 +64,35 @@ def last(symbols=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     symbols = _strToList(symbols)
     if symbols:
-        return _getJson('tops/last?symbols=' + ','.join(symbols) + '%2b', token, version)
-    return _getJson('tops/last', token, version)
+        return _getJson(
+            "tops/last?symbols=" + ",".join(symbols) + "%2b", token, version
+        )
+    return _getJson("tops/last", token, version)
 
 
 @wraps(last)
-async def lastAsync(symbols=None, token='', version=''):
+async def lastAsync(symbols=None, token="", version=""):
     symbols = _strToList(symbols)
     if symbols:
-        return await _getJsonAsync('tops/last?symbols=' + ','.join(symbols) + '%2b', token, version)
-    return await _getJsonAsync('tops/last', token, version)
+        return await _getJsonAsync(
+            "tops/last?symbols=" + ",".join(symbols) + "%2b", token, version
+        )
+    return await _getJsonAsync("tops/last", token, version)
 
 
 @wraps(last)
-def lastDF(symbols=None, token='', version=''):
-    df = pd.io.json.json_normalize(last(symbols, token, version))
+def lastDF(symbols=None, token="", version=""):
+    df = json_normalize(last(symbols, token, version))
     _toDatetime(df)
-    _reindex(df, 'symbol')
+    _reindex(df, "symbol")
     return df
 
 
-def deep(symbol=None, token='', version=''):
-    '''DEEP is used to receive real-time depth of book quotations direct from IEX.
+def deep(symbol=None, token="", version=""):
+    """DEEP is used to receive real-time depth of book quotations direct from IEX.
     The depth of book quotations received via DEEP provide an aggregated size of resting displayed orders at a price and side,
     and do not indicate the size or number of individual orders at any price level.
     Non-displayed orders and non-displayed portions of reserve orders are not represented in DEEP.
@@ -93,30 +108,30 @@ def deep(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep?symbols=' + symbol, token, version)
-    return _getJson('deep', token, version)
+        return _getJson("deep?symbols=" + symbol, token, version)
+    return _getJson("deep", token, version)
 
 
 @wraps(deep)
-async def deepAsync(symbol=None, token='', version=''):
+async def deepAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep', token, version)
+        return await _getJsonAsync("deep?symbols=" + symbol, token, version)
+    return await _getJsonAsync("deep", token, version)
 
 
 @wraps(deep)
-def deepDF(symbol=None, token='', version=''):
-    df = pd.io.json.json_normalize(deep(symbol, token, version))
+def deepDF(symbol=None, token="", version=""):
+    df = json_normalize(deep(symbol, token, version))
     _toDatetime(df)
     return df
 
 
-def auction(symbol=None, token='', version=''):
-    '''DEEP broadcasts an Auction Information Message every one second between the Lock-in Time and the auction match for Opening and Closing Auctions,
+def auction(symbol=None, token="", version=""):
+    """DEEP broadcasts an Auction Information Message every one second between the Lock-in Time and the auction match for Opening and Closing Auctions,
     and during the Display Only Period for IPO, Halt, and Volatility Auctions. Only IEX listed securities are eligible for IEX Auctions.
 
     https://iexcloud.io/docs/api/#deep-auction
@@ -128,30 +143,30 @@ def auction(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/auction?symbols=' + symbol, token, version)
-    return _getJson('deep/auction', token, version)
+        return _getJson("deep/auction?symbols=" + symbol, token, version)
+    return _getJson("deep/auction", token, version)
 
 
 @wraps(auction)
-async def auctionAsync(symbol=None, token='', version=''):
+async def auctionAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/auction?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/auction', token, version)
+        return await _getJsonAsync("deep/auction?symbols=" + symbol, token, version)
+    return await _getJsonAsync("deep/auction", token, version)
 
 
 @wraps(auction)
-def auctionDF(symbol=None, token='', version=''):
-    df = pd.io.json.json_normalize(auction(symbol, token, version))
+def auctionDF(symbol=None, token="", version=""):
+    df = json_normalize(auction(symbol, token, version))
     _toDatetime(df)
     return df
 
 
-def book(symbol=None, token='', version=''):
-    '''Book shows IEX’s bids and asks for given symbols.
+def book(symbol=None, token="", version=""):
+    """Book shows IEX’s bids and asks for given symbols.
 
     https://iexcloud.io/docs/api/#deep-book
 
@@ -162,36 +177,36 @@ def book(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/book?symbols=' + symbol, token, version)
-    return _getJson('deep/book', token, version)
+        return _getJson("deep/book?symbols=" + symbol, token, version)
+    return _getJson("deep/book", token, version)
 
 
 @wraps(book)
-async def bookAsync(symbol=None, token='', version=''):
+async def bookAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/book?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/book', token, version)
+        return await _getJsonAsync("deep/book?symbols=" + symbol, token, version)
+    return await _getJsonAsync("deep/book", token, version)
 
 
 @wraps(book)
-def bookDF(symbol=None, token='', version=''):
+def bookDF(symbol=None, token="", version=""):
     x = book(symbol, token, version)
     data = []
     for key in x:
         d = x[key]
-        d['symbol'] = key
+        d["symbol"] = key
         data.append(d)
-    df = pd.io.json.json_normalize(data)
+    df = json_normalize(data)
     _toDatetime(df)
     return df
 
 
-def opHaltStatus(symbol=None, token='', version=''):
-    '''The Exchange may suspend trading of one or more securities on IEX for operational reasons and indicates such operational halt using the Operational halt status message.
+def opHaltStatus(symbol=None, token="", version=""):
+    """The Exchange may suspend trading of one or more securities on IEX for operational reasons and indicates such operational halt using the Operational halt status message.
 
     IEX disseminates a full pre-market spin of Operational halt status messages indicating the operational halt status of all securities.
     In the spin, IEX will send out an Operational Halt Message with “N” (Not operationally halted on IEX) for all securities that are eligible for trading at the start of the Pre-Market Session.
@@ -208,36 +223,38 @@ def opHaltStatus(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/op-halt-status?symbols=' + symbol, token, version)
-    return _getJson('deep/op-halt-status', token, version)
+        return _getJson("deep/op-halt-status?symbols=" + symbol, token, version)
+    return _getJson("deep/op-halt-status", token, version)
 
 
 @wraps(opHaltStatus)
-async def opHaltStatusAsync(symbol=None, token='', version=''):
+async def opHaltStatusAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/op-halt-status?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/op-halt-status', token, version)
+        return await _getJsonAsync(
+            "deep/op-halt-status?symbols=" + symbol, token, version
+        )
+    return await _getJsonAsync("deep/op-halt-status", token, version)
 
 
 @wraps(opHaltStatus)
-def opHaltStatusDF(symbol=None, token='', version=''):
+def opHaltStatusDF(symbol=None, token="", version=""):
     x = opHaltStatus(symbol, token, version)
     data = []
     for key in x:
         d = x[key]
-        d['symbol'] = key
+        d["symbol"] = key
         data.append(d)
     df = pd.DataFrame(data)
     _toDatetime(df)
     return df
 
 
-def officialPrice(symbol=None, token='', version=''):
-    '''The Official Price message is used to disseminate the IEX Official Opening and Closing Prices.
+def officialPrice(symbol=None, token="", version=""):
+    """The Official Price message is used to disseminate the IEX Official Opening and Closing Prices.
 
     These messages will be provided only for IEX Listed Securities.
 
@@ -250,30 +267,32 @@ def officialPrice(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/official-price?symbols=' + symbol, token, version)
-    return _getJson('deep/official-price', token, version)
+        return _getJson("deep/official-price?symbols=" + symbol, token, version)
+    return _getJson("deep/official-price", token, version)
 
 
 @wraps(officialPrice)
-async def officialPriceAsync(symbol=None, token='', version=''):
+async def officialPriceAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/official-price?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/official-price', token, version)
+        return await _getJsonAsync(
+            "deep/official-price?symbols=" + symbol, token, version
+        )
+    return await _getJsonAsync("deep/official-price", token, version)
 
 
 @wraps(officialPrice)
-def officialPriceDF(symbol=None, token='', version=''):
-    df = pd.io.json.json_normalize(officialPrice(symbol, token, version))
+def officialPriceDF(symbol=None, token="", version=""):
+    df = json_normalize(officialPrice(symbol, token, version))
     _toDatetime(df)
     return df
 
 
-def securityEvent(symbol=None, token='', version=''):
-    '''The Security event message is used to indicate events that apply to a security. A Security event message will be sent whenever such event occurs
+def securityEvent(symbol=None, token="", version=""):
+    """The Security event message is used to indicate events that apply to a security. A Security event message will be sent whenever such event occurs
 
     https://iexcloud.io/docs/api/#deep-security-event
 
@@ -284,36 +303,38 @@ def securityEvent(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/security-event?symbols=' + symbol, token, version)
-    return _getJson('deep/security-event', token, version)
+        return _getJson("deep/security-event?symbols=" + symbol, token, version)
+    return _getJson("deep/security-event", token, version)
 
 
 @wraps(securityEvent)
-async def securityEventAsync(symbol=None, token='', version=''):
+async def securityEventAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/security-event?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/security-event', token, version)
+        return await _getJsonAsync(
+            "deep/security-event?symbols=" + symbol, token, version
+        )
+    return await _getJsonAsync("deep/security-event", token, version)
 
 
 @wraps(securityEvent)
-def securityEventDF(symbol=None, token='', version=''):
+def securityEventDF(symbol=None, token="", version=""):
     x = securityEvent(symbol, token, version)
     data = []
     for key in x:
         d = x[key]
-        d['symbol'] = key
+        d["symbol"] = key
         data.append(d)
     df = pd.DataFrame(data)
     _toDatetime(df)
     return df
 
 
-def ssrStatus(symbol=None, token='', version=''):
-    '''In association with Rule 201 of Regulation SHO, the Short Sale Price Test Message is used to indicate when a short sale price test restriction is in effect for a security.
+def ssrStatus(symbol=None, token="", version=""):
+    """In association with Rule 201 of Regulation SHO, the Short Sale Price Test Message is used to indicate when a short sale price test restriction is in effect for a security.
 
     IEX disseminates a full pre-market spin of Short sale price test status messages indicating the Rule 201 status of all securities.
      After the pre-market spin, IEX will use the Short sale price test status message in the event of an intraday status change.
@@ -329,24 +350,24 @@ def ssrStatus(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/ssr-status?symbols=' + symbol, token, version)
-    return _getJson('deep/ssr-status', token, version)
+        return _getJson("deep/ssr-status?symbols=" + symbol, token, version)
+    return _getJson("deep/ssr-status", token, version)
 
 
 @wraps(ssrStatus)
-async def ssrStatusAsync(symbol=None, token='', version=''):
+async def ssrStatusAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/ssr-status?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/ssr-status', token, version)
+        return await _getJsonAsync("deep/ssr-status?symbols=" + symbol, token, version)
+    return await _getJsonAsync("deep/ssr-status", token, version)
 
 
 @wraps(ssrStatus)
-def ssrStatusDF(symbol=None, token='', version=''):
-    '''In association with Rule 201 of Regulation SHO, the Short Sale Price Test Message is used to indicate when a short sale price test restriction is in effect for a security.
+def ssrStatusDF(symbol=None, token="", version=""):
+    """In association with Rule 201 of Regulation SHO, the Short Sale Price Test Message is used to indicate when a short sale price test restriction is in effect for a security.
 
     IEX disseminates a full pre-market spin of Short sale price test status messages indicating the Rule 201 status of all securities.
      After the pre-market spin, IEX will use the Short sale price test status message in the event of an intraday status change.
@@ -362,20 +383,20 @@ def ssrStatusDF(symbol=None, token='', version=''):
 
     Returns:
         DataFrame: result
-    '''
+    """
     x = ssrStatus(symbol, token, version)
     data = []
     for key in x:
         d = x[key]
-        d['symbol'] = key
+        d["symbol"] = key
         data.append(d)
     df = pd.DataFrame(data)
     _toDatetime(df)
     return df
 
 
-def systemEvent(token='', version=''):
-    '''The System event message is used to indicate events that apply to the market or the data feed.
+def systemEvent(token="", version=""):
+    """The System event message is used to indicate events that apply to the market or the data feed.
 
     There will be a single message disseminated per channel for each System Event type within a given trading session.
 
@@ -387,24 +408,24 @@ def systemEvent(token='', version=''):
 
     Returns:
         dict: result
-    '''
-    return _getJson('deep/system-event', token, version)
+    """
+    return _getJson("deep/system-event", token, version)
 
 
 @wraps(systemEvent)
-async def systemEventAsync(token='', version=''):
-    return await _getJsonAsync('deep/system-event', token, version)
+async def systemEventAsync(token="", version=""):
+    return await _getJsonAsync("deep/system-event", token, version)
 
 
 @wraps(systemEvent)
-def systemEventDF(token='', version=''):
-    df = pd.io.json.json_normalize(systemEvent(token, version))
+def systemEventDF(token="", version=""):
+    df = json_normalize(systemEvent(token, version))
     _toDatetime(df)
     return df
 
 
-def trades(symbol=None, token='', version=''):
-    '''Trade report messages are sent when an order on the IEX Order Book is executed in whole or in part. DEEP sends a Trade report message for every individual fill.
+def trades(symbol=None, token="", version=""):
+    """Trade report messages are sent when an order on the IEX Order Book is executed in whole or in part. DEEP sends a Trade report message for every individual fill.
 
     https://iexcloud.io/docs/api/#deep-trades
 
@@ -415,37 +436,37 @@ def trades(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/trades?symbols=' + symbol, token, version)
-    return _getJson('deep/trades', token, version)
+        return _getJson("deep/trades?symbols=" + symbol, token, version)
+    return _getJson("deep/trades", token, version)
 
 
 @wraps(trades)
-async def tradesAsync(symbol=None, token='', version=''):
+async def tradesAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/trades?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/trades', token, version)
+        return await _getJsonAsync("deep/trades?symbols=" + symbol, token, version)
+    return await _getJsonAsync("deep/trades", token, version)
 
 
 @wraps(trades)
-def tradesDF(symbol=None, token='', version=''):
+def tradesDF(symbol=None, token="", version=""):
     x = trades(symbol, token, version)
     data = []
     for key in x:
         dat = x[key]
         for d in dat:
-            d['symbol'] = key
+            d["symbol"] = key
             data.append(d)
     df = pd.DataFrame(data)
     _toDatetime(df)
     return df
 
 
-def tradeBreak(symbol=None, token='', version=''):
-    '''Trade break messages are sent when an execution on IEX is broken on that same trading day. Trade breaks are rare and only affect applications that rely upon IEX execution based data.
+def tradeBreak(symbol=None, token="", version=""):
+    """Trade break messages are sent when an execution on IEX is broken on that same trading day. Trade breaks are rare and only affect applications that rely upon IEX execution based data.
 
     https://iexcloud.io/docs/api/#deep-trade-break
 
@@ -457,30 +478,32 @@ def tradeBreak(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/trade-breaks?symbols=' + symbol, token, version)
-    return _getJson('deep/trade-breaks', token, version)
+        return _getJson("deep/trade-breaks?symbols=" + symbol, token, version)
+    return _getJson("deep/trade-breaks", token, version)
 
 
 @wraps(tradeBreak)
-async def tradeBreakAsync(symbol=None, token='', version=''):
+async def tradeBreakAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/trade-breaks?symbols=' + symbol, token, version)
-    return await _getJsonAsync('deep/trade-breaks', token, version)
+        return await _getJsonAsync(
+            "deep/trade-breaks?symbols=" + symbol, token, version
+        )
+    return await _getJsonAsync("deep/trade-breaks", token, version)
 
 
 @wraps(tradeBreak)
-def tradeBreakDF(symbol=None, token='', version=''):
-    df = pd.io.json.json_normalize(tradeBreak(symbol, token, version))
+def tradeBreakDF(symbol=None, token="", version=""):
+    df = json_normalize(tradeBreak(symbol, token, version))
     _toDatetime(df)
     return df
 
 
-def tradingStatus(symbol=None, token='', version=''):
-    '''The Trading status message is used to indicate the current trading status of a security.
+def tradingStatus(symbol=None, token="", version=""):
+    """The Trading status message is used to indicate the current trading status of a security.
      For IEX-listed securities, IEX acts as the primary market and has the authority to institute a trading halt or trading pause in a security due to news dissemination or regulatory reasons.
      For non-IEX-listed securities, IEX abides by any regulatory trading halts and trading pauses instituted by the primary or listing market, as applicable.
 
@@ -506,36 +529,38 @@ def tradingStatus(symbol=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if symbol:
-        return _getJson('deep/trading-status?symbols=' + symbol, token, version)
-    return _getJson('deep/trading-status', token, version)
+        return _getJson("deep/trading-status?symbols=" + symbol, token, version)
+    return _getJson("deep/trading-status", token, version)
 
 
 @wraps(tradingStatus)
-async def tradingStatusAsync(symbol=None, token='', version=''):
+async def tradingStatusAsync(symbol=None, token="", version=""):
     _raiseIfNotStr(symbol)
     if symbol:
-        return await _getJsonAsync('deep/trading-status?symbols=' + symbol, token, version)
-    return await _getJson('deep/trading-status', token, version)
+        return await _getJsonAsync(
+            "deep/trading-status?symbols=" + symbol, token, version
+        )
+    return await _getJson("deep/trading-status", token, version)
 
 
 @wraps(tradingStatus)
-def tradingStatusDF(symbol=None, token='', version=''):
+def tradingStatusDF(symbol=None, token="", version=""):
     x = tradingStatus(symbol, token, version)
     data = []
     for key in x:
         d = x[key]
-        d['symbol'] = key
+        d["symbol"] = key
         data.append(d)
     df = pd.DataFrame(data)
     _toDatetime(df)
     return df
 
 
-def hist(date=None, token='', version=''):
-    '''
+def hist(date=None, token="", version=""):
+    """
     Args:
         date (datetime): Effective date
         token (str): Access token
@@ -543,35 +568,35 @@ def hist(date=None, token='', version=''):
 
     Returns:
         dict: result
-    '''
+    """
 
     if date is None:
-        return _getJson('hist', token, version)
+        return _getJson("hist", token, version)
     else:
         date = _strOrDate(date)
-        return _getJson('hist?date=' + date, token, version)
+        return _getJson("hist?date=" + date, token, version)
 
 
 @wraps(hist)
-async def histAsync(date=None, token='', version=''):
+async def histAsync(date=None, token="", version=""):
     if date is None:
-        return await _getJson('hist', token, version)
+        return await _getJson("hist", token, version)
     else:
         date = _strOrDate(date)
-        return await _getJsonAsync('hist?date=' + date, token, version)
+        return await _getJsonAsync("hist?date=" + date, token, version)
 
 
 @wraps(hist)
-def histDF(date=None, token='', version=''):
-    '''https://iextrading.com/developer/docs/#hist'''
+def histDF(date=None, token="", version=""):
+    """https://iextrading.com/developer/docs/#hist"""
     x = hist(date, token, version)
     data = []
     for key in x:
         dat = x[key]
         for item in dat:
-            item['date'] = key
+            item["date"] = key
             data.append(item)
     df = pd.DataFrame(data)
     _toDatetime(df)
-    _reindex(df, 'date')
+    _reindex(df, "date")
     return df
