@@ -4,8 +4,8 @@ from functools import wraps
 from ..common import _getJson, _raiseIfNotStr, _toDatetime
 
 
-def points(symbol='market', key='', token='', version='', filter=''):
-    '''Data points are available per symbol and return individual plain text values.
+def points(symbol="market", key="", token="", version="", filter=""):
+    """Data points are available per symbol and return individual plain text values.
     Retrieving individual data points is useful for Excel and Google Sheet users, and applications where a single, lightweight value is needed.
     We also provide update times for some endpoints which allow you to call an endpoint only once it has new data.
 
@@ -21,19 +21,26 @@ def points(symbol='market', key='', token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
     if key:
-        return _getJson('data-points/{symbol}/{key}'.format(symbol=symbol, key=key), token, version, filter)
-    return _getJson('data-points/{symbol}'.format(symbol=symbol), token, version, filter)
+        return _getJson(
+            "data-points/{symbol}/{key}".format(symbol=symbol, key=key),
+            token,
+            version,
+            filter,
+        )
+    return _getJson(
+        "data-points/{symbol}".format(symbol=symbol), token, version, filter
+    )
 
 
 @wraps(points)
-def pointsDF(symbol='market', key='', token='', version='', filter=''):
+def pointsDF(symbol="market", key="", token="", version="", filter=""):
     _raiseIfNotStr(symbol)
     if key:
         val = points(symbol, key, token, version, filter)
-        return pd.DataFrame([{'symbol': symbol, 'key': key, 'value': val}])
+        return pd.DataFrame([{"symbol": symbol, "key": key, "value": val}])
     df = pd.DataFrame(points(symbol, key, token, version, filter))
     _toDatetime(df)
     return df
