@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
-import pandas as pd
 from functools import wraps
-from ...common import _getJson, PyEXception, _toDatetime, _strOrDate, _raiseIfNotStr
+from ...common import (
+    _getJson,
+    PyEXception,
+    _toDatetime,
+    _strOrDate,
+    _raiseIfNotStr,
+    json_normalize,
+)
 
 
-def socialSentiment(symbol,
-                    type='daily',
-                    date='',
-                    token='',
-                    version='',
-                    filter=''):
-    '''This endpoint provides social sentiment data from StockTwits. Data can be viewed as a daily value, or by minute for a given date.
+def socialSentiment(symbol, type="daily", date="", token="", version="", filter=""):
+    """This endpoint provides social sentiment data from StockTwits. Data can be viewed as a daily value, or by minute for a given date.
 
     https://iexcloud.io/docs/api/#social-sentiment
 
@@ -24,21 +25,21 @@ def socialSentiment(symbol,
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
 
-    if type not in ('daily', 'minute'):
-        raise PyEXception('`type` must be in (daily, minute). Got: {}'.format(type))
-    base_url = 'stock/{}/sentiment/{}'.format(symbol, type)
+    if type not in ("daily", "minute"):
+        raise PyEXception("`type` must be in (daily, minute). Got: {}".format(type))
+    base_url = "stock/{}/sentiment/{}".format(symbol, type)
 
     if date:
         date = _strOrDate(date)
-        base_url += '/{}'.format(date)
+        base_url += "/{}".format(date)
     return _getJson(base_url, token, version, filter)
 
 
 @wraps(socialSentiment)
 def socialSentimentDF(*args, **kwargs):
-    df = pd.io.json.json_normalize(socialSentiment(*args, **kwargs))
+    df = json_normalize(socialSentiment(*args, **kwargs))
     _toDatetime(df)
     return df
