@@ -5,8 +5,8 @@ from ..common import _expire, _getJson
 
 
 @_expire(hour=8)
-def exchanges(token='', version='', filter=''):
-    '''Returns an array of U.S. exchanges.
+def exchanges(token="", version="", filter=""):
+    """Returns an array of U.S. exchanges.
 
     https://iexcloud.io/docs/api/#u-s-exchanges
     8am, 9am, 12pm, 1pm UTC daily
@@ -18,18 +18,18 @@ def exchanges(token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('ref-data/market/us/exchanges', token, version, filter)
+    """
+    return _getJson("ref-data/market/us/exchanges", token, version, filter)
 
 
 @wraps(exchanges)
-def exchangesDF(token='', version='', filter=''):
+def exchangesDF(token="", version="", filter=""):
     return pd.DataFrame(exchanges(token, version, filter))
 
 
 @_expire(hour=8)
-def internationalExchanges(token='', version='', filter=''):
-    '''Returns an array of exchanges.
+def internationalExchanges(token="", version="", filter=""):
+    """Returns an array of exchanges.
 
     https://iexcloud.io/docs/api/#international-exchanges
     8am, 9am, 12pm, 1pm UTC daily
@@ -41,10 +41,10 @@ def internationalExchanges(token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('ref-data/exchanges', token, version, filter)
+    """
+    return _getJson("ref-data/exchanges", token, version, filter)
 
 
 @wraps(internationalExchanges)
-def internationalExchangesDF(token='', version='', filter=''):
+def internationalExchangesDF(token="", version="", filter=""):
     return pd.DataFrame(internationalExchanges(token, version, filter))
