@@ -4,8 +4,8 @@ from functools import wraps
 from ..common import _getJson, _raiseIfNotStr
 
 
-def figi(figi_=None, token='', version=''):
-    '''Helper call to convert FIGI to IEX Cloud symbols. Note that due to licensing restrictions we are unable to return the FIGI.
+def figi(figi_=None, token="", version=""):
+    """Helper call to convert FIGI to IEX Cloud symbols. Note that due to licensing restrictions we are unable to return the FIGI.
 
     https://iexcloud.io/docs/api/#figi-mapping
 
@@ -16,11 +16,11 @@ def figi(figi_=None, token='', version=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(figi_)
-    return _getJson('ref-data/figi?figi={}'.format(figi_), token, version, None)
+    return _getJson("ref-data/figi?figi={}".format(figi_), token, version, None)
 
 
 @wraps(figi)
-def figiDF(figi_=None, token='', version=''):
+def figiDF(figi_=None, token="", version=""):
     return pd.DataFrame(figi(figi_, token, version))
