@@ -5,8 +5,8 @@ from functools import wraps
 from ..common import _expire, _getJson, PyEXception, _strOrDate, _reindex, _toDatetime
 
 
-def stats(token='', version='', filter=''):
-    '''https://iexcloud.io/docs/api/#stats-intraday
+def stats(token="", version="", filter=""):
+    """https://iexcloud.io/docs/api/#stats-intraday
 
     Args:
         token (str): Access token
@@ -15,19 +15,19 @@ def stats(token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('stats/intraday', token, version, filter)
+    """
+    return _getJson("stats/intraday", token, version, filter)
 
 
 @wraps(stats)
-def statsDF(token='', version='', filters=''):
+def statsDF(token="", version="", filters=""):
     df = pd.DataFrame(stats(token, version, filter))
     _toDatetime(df)
     return df
 
 
-def recent(token='', version='', filter=''):
-    '''https://iexcloud.io/docs/api/#stats-recent
+def recent(token="", version="", filter=""):
+    """https://iexcloud.io/docs/api/#stats-recent
 
     Args:
         token (str): Access token
@@ -36,20 +36,20 @@ def recent(token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('stats/recent', token, version, filter)
+    """
+    return _getJson("stats/recent", token, version, filter)
 
 
 @wraps(recent)
-def recentDF(token='', version='', filter=''):
+def recentDF(token="", version="", filter=""):
     df = pd.DataFrame(recent(token, version, filter))
     _toDatetime(df)
-    _reindex(df, 'date')
+    _reindex(df, "date")
     return df
 
 
-def records(token='', version='', filter=''):
-    '''https://iexcloud.io/docs/api/#stats-records
+def records(token="", version="", filter=""):
+    """https://iexcloud.io/docs/api/#stats-records
 
     Args:
         token (str): Access token
@@ -58,20 +58,20 @@ def records(token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
-    return _getJson('stats/records', token, version, filter)
+    """
+    return _getJson("stats/records", token, version, filter)
 
 
 @wraps(records)
-def recordsDF(token='', version='', filter=''):
+def recordsDF(token="", version="", filter=""):
     df = pd.DataFrame(records(token, version, filter))
     _toDatetime(df)
     return df
 
 
 @_expire(hour=0)
-def summary(date=None, token='', version='', filter=''):
-    '''https://iexcloud.io/docs/api/#stats-historical-summary
+def summary(date=None, token="", version="", filter=""):
+    """https://iexcloud.io/docs/api/#stats-historical-summary
 
     Args:
         date (Optional[str]): Format YYYYMMDD date to fetch sentiment data. Default is today.
@@ -81,27 +81,31 @@ def summary(date=None, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     if date:
         if isinstance(date, str):
-            return _getJson('stats/historical?date=' + date, token, version, filter)
+            return _getJson("stats/historical?date=" + date, token, version, filter)
         elif isinstance(date, datetime):
-            return _getJson('stats/historical?date=' + date.strftime('%Y%m'), token, version, filter)
+            return _getJson(
+                "stats/historical?date=" + date.strftime("%Y%m"), token, version, filter
+            )
         else:
-            raise PyEXception("Can't handle type : %s" % str(type(date)), token, version, filter)
-    return _getJson('stats/historical', token, version, filter)
+            raise PyEXception(
+                "Can't handle type : %s" % str(type(date)), token, version, filter
+            )
+    return _getJson("stats/historical", token, version, filter)
 
 
 @wraps(summary)
-def summaryDF(date=None, token='', version='', filter=''):
+def summaryDF(date=None, token="", version="", filter=""):
     df = pd.DataFrame(summary(date, token, version, filter))
     _toDatetime(df)
     return df
 
 
 @_expire(hour=0)
-def daily(date=None, last='', token='', version='', filter=''):
-    '''https://iexcloud.io/docs/api/#stats-historical-daily
+def daily(date=None, last="", token="", version="", filter=""):
+    """https://iexcloud.io/docs/api/#stats-historical-daily
 
     Args:
         date (Optional[str]): Format YYYYMMDD date to fetch sentiment data. Default is today.
@@ -112,17 +116,17 @@ def daily(date=None, last='', token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     if date:
         date = _strOrDate(date)
-        return _getJson('stats/historical/daily?date=' + date, token, version, filter)
+        return _getJson("stats/historical/daily?date=" + date, token, version, filter)
     elif last:
-        return _getJson('stats/historical/daily?last=' + last, token, version, filter)
-    return _getJson('stats/historical/daily', token, version, filter)
+        return _getJson("stats/historical/daily?last=" + last, token, version, filter)
+    return _getJson("stats/historical/daily", token, version, filter)
 
 
 @wraps(daily)
-def dailyDF(date=None, last='', token='', version='', filter=''):
+def dailyDF(date=None, last="", token="", version="", filter=""):
     df = pd.DataFrame(daily(date, last, token, version, filter))
     _toDatetime(df)
     return df
