@@ -2,7 +2,17 @@
 import itertools
 import pandas as pd
 from multiprocessing.pool import ThreadPool
-from ..common import _TIMEFRAME_CHART, _getJson, _raiseIfNotStr, PyEXception, _strOrDate, _toDatetime, _BATCH_TYPES
+from ..common import (
+    _TIMEFRAME_CHART,
+    _getJson,
+    _raiseIfNotStr,
+    PyEXception,
+    _strOrDate,
+    _toDatetime,
+    _BATCH_TYPES,
+    json_normalize,
+    _quoteSymbols,
+)
 from .fundamentals import _dividendsToDF, _earningsToDF, _financialsToDF, _splitsToDF
 from .news import _newsToDF
 from .prices import chart, _bookToDF, _chartToDF
@@ -11,28 +21,28 @@ from .research import _statsToDF
 
 
 _MAPPING = {
-    'book': _bookToDF,
-    'chart': _chartToDF,
-    'company': _companyToDF,
-    'dividends': _dividendsToDF,
-    'earnings': _earningsToDF,
-    'financials': _financialsToDF,
-    'stats': _statsToDF,
-    'news': _newsToDF,
-    'peers': _peersToDF,
-    'splits': _splitsToDF
+    "book": _bookToDF,
+    "chart": _chartToDF,
+    "company": _companyToDF,
+    "dividends": _dividendsToDF,
+    "earnings": _earningsToDF,
+    "financials": _financialsToDF,
+    "stats": _statsToDF,
+    "news": _newsToDF,
+    "peers": _peersToDF,
+    "splits": _splitsToDF,
 }
 
 
-def batch(symbols, fields=None, range_='1m', last=10, token='', version='', filter=''):
-    '''Batch several data requests into one invocation
+def batch(symbols, fields=None, range_="1m", last=10, token="", version="", filter=""):
+    """Batch several data requests into one invocation. If no `fields` passed in, will default to `quote`
 
     https://iexcloud.io/docs/api/#batch-requests
 
 
     Args:
-        symbols (list): List of tickers to request
-        fields (list): List of fields to request
+        symbols (str or list): List of tickers to request
+        fields (str or list): List of fields to request
         range_ (str): Date range for chart
         last (int):
         token (str): Access token
@@ -41,31 +51,46 @@ def batch(symbols, fields=None, range_='1m', last=10, token='', version='', filt
 
     Returns:
         dict: results in json
-    '''
-    fields = fields or _BATCH_TYPES[:10]  # limit 10
+    """
+    fields = fields or "quote"
 
-    if not isinstance(symbols, [].__class__):
-        if not isinstance(symbols, str):
-            raise PyEXception('batch expects string or list of strings for symbols argument')
+    if not isinstance(symbols, [].__class__) and not isinstance(symbols, str):
+        raise PyEXception(
+            "batch expects string or list of strings for symbols argument"
+        )
 
-    if isinstance(fields, str):
+    if isinstance(fields, str) and "," not in fields:
         fields = [fields]
+    elif isinstance(fields, str):
+        fields = fields.split(",")
+
+    for field in fields:
+        if field not in _BATCH_TYPES:
+            raise PyEXception("Unrecognized batch request field: {}".format(field))
 
     if range_ not in _TIMEFRAME_CHART:
-        raise PyEXception('Range must be in %s' % str(_TIMEFRAME_CHART))
+        raise PyEXception("Range must be in %s" % str(_TIMEFRAME_CHART))
 
-    if isinstance(symbols, str):
-        route = 'stock/{}/batch?types={}&range={}&last={}'.format(symbols, ','.join(fields), range_, last)
-        return _getJson(route, token, version, filter)
+    symbols = _quoteSymbols(symbols)
+    if len(symbols.split(",")) > 100:
+        raise PyEXception("IEX will only handle up to 100 symbols at a time!")
+
+    if "," not in symbols:
+        route = "stock/{}/batch?types={}&range={}&last={}".format(
+            symbols, ",".join(fields), range_, last
+        )
+    else:
+        route = "stock/market/batch?symbols={}&types={}&range={}&last={}".format(
+            symbols, ",".join(fields), range_, last
+        )
 
-    if len(symbols) > 100:
-        raise PyEXception('IEX will only handle up to 100 symbols at a time!')
-    route = 'stock/market/batch?symbols={}&types={}&range={}&last={}'.format(','.join(symbols), ','.join(fields), range_, last)
     return _getJson(route, token, version, filter)
 
 
-def batchDF(symbols, fields=None, range_='1m', last=10, token='', version='', filter=''):
-    '''Batch several data requests into one invocation
+def batchDF(
+    symbols, fields=None, range_="1m", last=10, token="", version="", filter=""
+):
+    """Batch several data requests into one invocation
 
     https://iexcloud.io/docs/api/#batch-requests
 
@@ -81,30 +106,35 @@ def batchDF(symbols, fields=None, range_='1m', last=10, token='', version='', fi
 
     Returns:
         DataFrame: results in json
-    '''
+    """
+    symbols = _quoteSymbols(symbols)
     x = batch(symbols, fields, range_, last, token, version, filter)
 
     ret = {}
 
-    if isinstance(symbols, str):
+    if "," not in symbols:
+        # one level json, break down
         for field in x.keys():
-            ret[field] = _MAPPING.get(field, pd.io.json.json_normalize)(x[field])
+            ret[field] = _MAPPING.get(field, json_normalize)(x[field])
     else:
+        # two level json
         for symbol in x.keys():
             for field in x[symbol].keys():
                 if field not in ret:
                     ret[field] = pd.DataFrame()
 
                 dat = x[symbol][field]
-                dat = _MAPPING.get(field, pd.io.json.json_normalize)(dat)
-                dat['symbol'] = symbol
+                dat = _MAPPING.get(field, json_normalize)(dat)
+                dat["symbol"] = symbol
 
                 ret[field] = pd.concat([ret[field], dat], sort=True)
     return ret
 
 
-def bulkBatch(symbols, fields=None, range_='1m', last=10, token='', version='', filter=''):
-    '''Optimized batch to fetch as much as possible at once
+def bulkBatch(
+    symbols, fields=None, range_="1m", last=10, token="", version="", filter=""
+):
+    """Optimized batch to fetch as much as possible at once
 
     https://iexcloud.io/docs/api/#batch-requests
 
@@ -120,17 +150,17 @@ def bulkBatch(symbols, fields=None, range_='1m', last=10, token='', version='',
 
     Returns:
         dict: results in json
-    '''
+    """
     fields = fields or _BATCH_TYPES
     args = []
     empty_data = []
     list_orig = empty_data.__class__
 
     if not isinstance(symbols, list_orig):
-        raise PyEXception('Symbols must be of type list')
+        raise PyEXception("Symbols must be of type list")
 
     for i in range(0, len(symbols), 99):
-        args.append((symbols[i:i + 99], fields, range_, last, token, version, filter))
+        args.append((symbols[i : i + 99], fields, range_, last, token, version, filter))
 
     pool = ThreadPool(20)
     rets = pool.starmap(batch, args)
@@ -153,8 +183,10 @@ def bulkBatch(symbols, fields=None, range_='1m', last=10, token='', version='',
     return ret
 
 
-def bulkBatchDF(symbols, fields=None, range_='1m', last=10, token='', version='', filter=''):
-    '''Optimized batch to fetch as much as possible at once
+def bulkBatchDF(
+    symbols, fields=None, range_="1m", last=10, token="", version="", filter=""
+):
+    """Optimized batch to fetch as much as possible at once
 
     https://iexcloud.io/docs/api/#batch-requests
 
@@ -170,7 +202,7 @@ def bulkBatchDF(symbols, fields=None, range_='1m', last=10, token='', version=''
 
     Returns:
         DataFrame: results in json
-    '''
+    """
     dat = bulkBatch(symbols, fields, range_, last, token, version, filter)
     ret = {}
     for symbol in dat:
@@ -180,21 +212,21 @@ def bulkBatchDF(symbols, fields=None, range_='1m', last=10, token='', version=''
 
             d = dat[symbol][field]
             d = _MAPPING[field](d)
-            d['symbol'] = symbol
+            d["symbol"] = symbol
             ret[field] = pd.concat([ret[field], d], sort=True)
 
     return ret
 
 
-def bulkMinuteBars(symbol, dates, token='', version='', filter=''):
-    '''fetch many dates worth of minute-bars for a given symbol'''
+def bulkMinuteBars(symbol, dates, token="", version="", filter=""):
+    """fetch many dates worth of minute-bars for a given symbol"""
     _raiseIfNotStr(symbol)
     dates = [_strOrDate(date) for date in dates]
     list_orig = dates.__class__
 
     args = []
     for date in dates:
-        args.append((symbol, '1d', date, token, version, filter))
+        args.append((symbol, "1d", date, token, version, filter))
 
     pool = ThreadPool(20)
     rets = pool.starmap(chart, args)
@@ -203,12 +235,12 @@ def bulkMinuteBars(symbol, dates, token='', version='', filter=''):
     return list_orig(itertools.chain(*rets))
 
 
-def bulkMinuteBarsDF(symbol, dates, token='', version='', filter=''):
-    '''fetch many dates worth of minute-bars for a given symbol'''
+def bulkMinuteBarsDF(symbol, dates, token="", version="", filter=""):
+    """fetch many dates worth of minute-bars for a given symbol"""
     data = bulkMinuteBars(symbol, dates, token, version, filter)
     df = pd.DataFrame(data)
     if df.empty:
         return df
     _toDatetime(df)
-    df.set_index(['date', 'minute'], inplace=True)
+    df.set_index(["date", "minute"], inplace=True)
     return df
