@@ -1,16 +1,26 @@
 # -*- coding: utf-8 -*-
 import requests
 import pandas as pd
+from deprecation import deprecated
 from functools import wraps
 from IPython.display import Image as ImageI
 from io import BytesIO
 from PIL import Image as ImageP
-from ..common import _expire, _getJson, _raiseIfNotStr, _reindex, _toDatetime, _UTC
+from ..common import (
+    _expire,
+    _getJson,
+    _raiseIfNotStr,
+    _reindex,
+    _toDatetime,
+    _UTC,
+    json_normalize,
+    _quoteSymbols,
+)
 
 
 @_expire(hour=4, tz=_UTC)
-def company(symbol, token='', version='', filter=''):
-    '''Company reference data
+def company(symbol, token="", version="", filter=""):
+    """Company reference data
 
     https://iexcloud.io/docs/api/#company
     Updates at 4am and 5am UTC every day
@@ -23,29 +33,30 @@ def company(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/company', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/company", token, version, filter)
 
 
-def _companyToDF(c, token='', version='', filter=''):
-    '''internal'''
-    df = pd.io.json.json_normalize(c)
+def _companyToDF(c, token="", version="", filter=""):
+    """internal"""
+    df = json_normalize(c)
     _toDatetime(df)
-    _reindex(df, 'symbol')
+    _reindex(df, "symbol")
     return df
 
 
 @wraps(company)
-def companyDF(symbol, token='', version='', filter=''):
+def companyDF(symbol, token="", version="", filter=""):
     c = company(symbol, token, version, filter)
     df = _companyToDF(c)
     return df
 
 
 @_expire(hour=5, tz=_UTC)
-def insiderRoster(symbol, token='', version='', filter=''):
-    '''Returns the top 10 insiders, with the most recent information.
+def insiderRoster(symbol, token="", version="", filter=""):
+    """Returns the top 10 insiders, with the most recent information.
 
     https://iexcloud.io/docs/api/#insider-roster
     Updates at 5am, 6am ET every day
@@ -58,22 +69,23 @@ def insiderRoster(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/insider-roster', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/insider-roster", token, version, filter)
 
 
 @wraps(insiderRoster)
-def insiderRosterDF(symbol, token='', version='', filter=''):
+def insiderRosterDF(symbol, token="", version="", filter=""):
     val = insiderRoster(symbol, token, version, filter)
     df = pd.DataFrame(val)
-    _toDatetime(df, cols=[], tcols=['reportDate'])
+    _toDatetime(df, cols=[], tcols=["reportDate"])
     return df
 
 
 @_expire(hour=5, tz=_UTC)
-def insiderSummary(symbol, token='', version='', filter=''):
-    '''Returns aggregated insiders summary data for the last 6 months.
+def insiderSummary(symbol, token="", version="", filter=""):
+    """Returns aggregated insiders summary data for the last 6 months.
 
     https://iexcloud.io/docs/api/#insider-summary
     Updates at 5am, 6am ET every day
@@ -86,13 +98,14 @@ def insiderSummary(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/insider-summary', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/insider-summary", token, version, filter)
 
 
 @wraps(insiderSummary)
-def insiderSummaryDF(symbol, token='', version='', filter=''):
+def insiderSummaryDF(symbol, token="", version="", filter=""):
     val = insiderSummary(symbol, token, version, filter)
     df = pd.DataFrame(val)
     _toDatetime(df)
@@ -100,8 +113,8 @@ def insiderSummaryDF(symbol, token='', version='', filter=''):
 
 
 @_expire(hour=5, tz=_UTC)
-def insiderTransactions(symbol, token='', version='', filter=''):
-    '''Returns insider transactions.
+def insiderTransactions(symbol, token="", version="", filter=""):
+    """Returns insider transactions.
 
     https://iexcloud.io/docs/api/#insider-transactions
     Updates at UTC every day
@@ -114,13 +127,14 @@ def insiderTransactions(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/insider-transactions', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/insider-transactions", token, version, filter)
 
 
 @wraps(insiderTransactions)
-def insiderTransactionsDF(symbol, token='', version='', filter=''):
+def insiderTransactionsDF(symbol, token="", version="", filter=""):
     val = insiderTransactions(symbol, token, version, filter)
     df = pd.DataFrame(val)
     _toDatetime(df)
@@ -128,8 +142,8 @@ def insiderTransactionsDF(symbol, token='', version='', filter=''):
 
 
 @_expire(hour=0, tz=_UTC)
-def logo(symbol, token='', version='', filter=''):
-    '''This is a helper function, but the google APIs url is standardized.
+def logo(symbol, token="", version="", filter=""):
+    """This is a helper function, but the google APIs url is standardized.
 
     https://iexcloud.io/docs/api/#logo
     8am UTC daily
@@ -142,14 +156,15 @@ def logo(symbol, token='', version='', filter=''):
 
     Returns:
         dict: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/logo', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/logo", token, version, filter)
 
 
 @_expire(hour=0, tz=_UTC)
-def logoPNG(symbol, token='', version='', filter=''):
-    '''This is a helper function, but the google APIs url is standardized.
+def logoPNG(symbol, token="", version="", filter=""):
+    """This is a helper function, but the google APIs url is standardized.
 
     https://iexcloud.io/docs/api/#logo
     8am UTC daily
@@ -162,15 +177,16 @@ def logoPNG(symbol, token='', version='', filter=''):
 
     Returns:
         image: result as png
-    '''
+    """
     _raiseIfNotStr(symbol)
-    response = requests.get(logo(symbol, token, version, filter)['url'])
+    symbol = _quoteSymbols(symbol)
+    response = requests.get(logo(symbol, token, version, filter)["url"])
     return ImageP.open(BytesIO(response.content))
 
 
 @_expire(hour=0, tz=_UTC)
-def logoNotebook(symbol, token='', version='', filter=''):
-    '''This is a helper function, but the google APIs url is standardized.
+def logoNotebook(symbol, token="", version="", filter=""):
+    """This is a helper function, but the google APIs url is standardized.
 
     https://iexcloud.io/docs/api/#logo
     8am UTC daily
@@ -183,15 +199,16 @@ def logoNotebook(symbol, token='', version='', filter=''):
 
     Returns:
         image: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    url = logo(symbol, token, version, filter)['url']
+    symbol = _quoteSymbols(symbol)
+    url = logo(symbol, token, version, filter)["url"]
     return ImageI(url=url)
 
 
 @_expire(hour=8, tz=_UTC)
-def peers(symbol, token='', version='', filter=''):
-    '''Peers of ticker
+def peers(symbol, token="", version="", filter=""):
+    """Peers of ticker
 
     https://iexcloud.io/docs/api/#peers
     8am UTC daily
@@ -204,30 +221,32 @@ def peers(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/peers', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/peers", token, version, filter)
 
 
 def _peersToDF(p):
-    '''internal'''
-    df = pd.DataFrame(p, columns=['symbol'])
+    """internal"""
+    df = pd.DataFrame(p, columns=["symbol"])
     _toDatetime(df)
-    _reindex(df, 'symbol')
-    df['peer'] = df.index
+    _reindex(df, "symbol")
+    df["peer"] = df.index
     return df
 
 
 @wraps(peers)
-def peersDF(symbol, token='', version='', filter=''):
+def peersDF(symbol, token="", version="", filter=""):
     p = peers(symbol, token, version, filter)
     df = _peersToDF(p)
     return df
 
 
 @_expire(hour=8, tz=_UTC)
-def relevant(symbol, token='', version='', filter=''):
-    '''Same as peers
+@deprecated(details="Deprecated: IEX Cloud status unkown")
+def relevant(symbol, token="", version="", filter=""):
+    """Same as peers
 
     https://iexcloud.io/docs/api/#relevant
     Args:
@@ -238,13 +257,15 @@ def relevant(symbol, token='', version='', filter=''):
 
     Returns:
         dict or DataFrame: result
-    '''
+    """
     _raiseIfNotStr(symbol)
-    return _getJson('stock/' + symbol + '/relevant', token, version, filter)
+    symbol = _quoteSymbols(symbol)
+    return _getJson("stock/" + symbol + "/relevant", token, version, filter)
 
 
 @wraps(relevant)
-def relevantDF(symbol, token='', version='', filter=''):
+@deprecated(details="Deprecated: IEX Cloud status unkown")
+def relevantDF(symbol, token="", version="", filter=""):
     df = pd.DataFrame(relevant(symbol, token, version, filter))
     _toDatetime(df)
     return df
