@@ -5,9 +5,9 @@ from mock import patch
 class TestEconomic:
     def test_all(self):
         from pyEX import Client
-        c = Client('test')
-        with patch('pyEX.common._getJsonIEXCloud'), \
-                patch('pickle.dump'):
+
+        c = Client("test")
+        with patch("pyEX.common._getJsonIEXCloud"), patch("pickle.dump"):
             c.us30()
             c.us15()
             c.us5()
